from IutyLib.coding.tdd import setup,case
from IutyLib.coding.asserts import assertEqual,assertTrue,assertFalse
import importlib


from IutyLib.coding.tdd import ins_MethodTest, test_process
ins_MethodTest._testmode  = True

@case("a example of static test")
def test_import():
    m = setup("test8")
    
    assertTrue(not m is None,"import module success")
    pass

@case("a example of static test",mustpass=["test_import"])
def test_add():
    m = setup("test0")
    v = m.add(3,5)
    assertEqual(v,9)

lib = "test0"
importlib.__import__(lib)

test_process(r"d:/")




from TestProxy import test as t
from TestProxy import setup,ins_MethodTest
from TestProxy import case,assertEqual,assertTrue

ins_MethodTest._testmode = True





@case()
def test_add():
    m = setup("test")
    v = m.add(1,1)
    assert v == 2
    #assert v == 3,"运算结果不正确"
    assertEqual(v,2)
    
    assertEqual(v,3,"not exactly")
    pass


class Demo:
    
    
    @case(msg="do test")
    def test_pinus(msg="do test"):
        m = setup("test")
        v = m.pinus(5,3)
        assertEqual(v,2.0,"type same?")
        
        assertTrue(1!=1,"1!=1")
        
t()


from IutyLib.commonutil.convert import str2float

from IutyLib.coding.tdd import case
from IutyLib.coding.asserts import assertEqual

def add(a,b):
    return a+b

def pinus(a,b):
    return a-b

@case()
def test_add():
    v = add(5,9)
    assertEqual(v,14)





def setDict(dictionary,keys,value):
	dic = dictionary
	for i in range(len(keys)-1):
		if keys[i] not in dic:
			dic[keys[i]] = {}
		dic = dic[keys[i]]
	dic[keys[-1]] = value
	pass

def getDict(dictionary,keys):
	dic = dictionary
	for key in keys:
		if key in dic:
			dic = dic[key]
		else:
			return None
	return dic

def testDict():
	dictionary = {}
	keys = ['config','test','111']
	setDict(dictionary,keys,111)
	print(dictionary)
	print(getDict(dictionary,keys))

if __name__ == '__main__':
	testDict()



from setuptools import setup

version = "1.0"
try:
    from IutyLib.commonutil.config import Config
    config = Config("./Config.conf")
    ver = config.get("Version","ver")
    subver = config.get("Version","subver")
    version= "{}.{}".format(ver,subver)
except ImportError:
    print("Import Error")

packages = [
        #"IutyLib",
        "IutyLib.commonutil",
        "IutyLib.coding",
        "IutyLib.database",
        "IutyLib.file",
        "IutyLib.stock",
        "IutyLib.tensor",
        "IutyLib.monitor",
        "IutyLib.notice",
        "IutyLib.framework",
        "IutyLib.encription",
        "IutyLib.show",
        "IutyLib.mutithread",
        "IutyLib.useright",
        "IutyLib.method",
        ]

install_requires = ['pyDes',]

setup(
    name="IutyLib",
    version= version,
    #version = ver,
    packages=packages,
    install_requires = install_requires
)


import importlib,os,sys,time,json

class BaseTest:
    _testmode = False
    
    _modules_ = []
    
    _cases_ = []
    msg = ""
    mastpass = []
    pass

def assertImport(module):
    try:
        m = importlib.import_module(module)
        return m
    except Exception as err:
        #print(r"引入模块[{}]异常！".format(module))
        raise AssertionError(r"import [{}] failed！because:{}".format(module,str(err)))
    pass


def assertEqual(arg1,arg2,msg = None):
    assertmsg = r"{} is not equal to {}".format(arg1,arg2)
    if msg:
        assertmsg += " ({})".format(msg)
    assert arg1 == arg2,assertmsg

def assertTrue(expr,msg = None):
    if not msg:
        msg = "assert"
    assertmsg = r"{} is not a true expression".format(msg)
    
    assert expr,assertmsg

def setup(module,reload=True):
    #if modulepath ins_MethodTest._modules_
    abspath = os.path.abspath(module)
    """
    if abspath in ins_MethodTest._modules_:
        if reload:
            importlib.reload(module)
            print(r"reload [{}] successed!".format(module))
        return
    """
    try:
        m = assertImport(module)
        print(r"import [{}] successed！".format(module))
        ins_MethodTest._modules_.append(abspath)
        return m
    except AssertionError as err:
        print(err)
    
    #print(ins_MethodTest._modules_)
    pass

def case(msg = "have not set message yet",mastpass=[]):
    
    ins_MethodTest.msg = msg
    ins_MethodTest.mastpass = mastpass
    return testfuncwrapper
    
def testfuncwrapper(func):
    if ins_MethodTest._testmode:
        ins_MethodTest._cases_.append({'file':func.__globals__['__file__'],'name':func.__name__,'func':func,'msg':ins_MethodTest.msg,"mastpass":ins_MethodTest.mastpass})
    
    return func

def test(resultpath=r"./"):
    rtn = {"spend":0.0,"cases":{}}
    gs = time.time()
    for testcase in ins_MethodTest._cases_:
        file = testcase["file"]
        name = testcase["name"]
        func = testcase["func"]
        print('-'*20)
        if not file in rtn["cases"]:
            rtn["cases"][file] = {}
        rtn["cases"][file][name] = {}
        
        report = rtn["cases"][file][name]
        cs = time.time()
        
        try:
            func()
            print("{} test passed".format(name))
            report["result"] = "passed"
            
        except AssertionError as err:
            
            print("[line:{}] {} test failed! ({})".format(err.__traceback__.tb_next.tb_lineno,name,str(err)))
            report["result"] = "failed"
            report["message"] = "[line:{}]:{}".format(err.__traceback__.tb_next.tb_lineno,str(err))
            
        ce = time.time()
        report["spend"] = round(ce-cs,3)
    ge = time.time()
    rtn["spend"] = round(ge-gs,3)
    
    try:
        resultfile = os.path.join(resultpath,"rst.txt")
        with open(resultfile,'w') as f:
            json.dump(rtn,f,indent = 4)
    except Exception as err:
        print("Save test result failed;")
        print(err)
    pass


class MethodTest(BaseTest):
    
    pass


    
ins_MethodTest = MethodTest()